.slider_container .slider {
    margin: 0 24px;
}
.slider_container .ui-slider-handle {
    width: 3em !important;
    height: 1.6em !important;
    top: 50% !important;
    margin-top: -.8em;
    margin-left: -1.5em !important;
    text-align: center;
    line-height: 1.6em;
    cursor: pointer !important;
    font-weight: bold;
    outline: none !important;
}