.output_image_holder {
  width: 100%;
  height: 100%;
  display: flex;
  justify-content: center;
  align-items: center;
}
.output_image {
  width: 100%;
  height: 100%;
  object-fit: contain;
  display: none;
}
