.panels {
  margin-top: -24px;
  margin-left: -16px;
}
.panel {
  margin-top: 24px;
  margin-left: 16px;
  min-width: 300px;
  flex: 1 1 0;
  display: flex;
  flex-direction: column;
  box-sizing: border-box;
}
.panel_header {
  text-transform: uppercase;
  color: black;
  font-size: 14px;
  font-weight: bold;
  display: flex;
  margin-bottom: 8px;
}
.input_interfaces, .output_interfaces {
  margin-bottom: 16px;
  background-color: whitesmoke;
  border-radius: 4px;
  padding: 12px;
  flex-grow: 1;
}
.interface {
  display: flex;
  flex-flow: column;
}
.interface_box {
  height: 360px;
}
.interface_mini_box {
  height: 180px;
}
.interface_max_box {
  overflow: auto;
  max-height: 360px;
}
.interface:not(*:last-child) {
  margin-bottom: 16px;
}
.output_panel {
  position: relative;
}
.loading {
  position: absolute;
  top: 3px;
  right: 3px;
  margin-left: auto;
  z-index: 1;
}
.loading img {
  height: 20px;
  display: none;
}
.panel_buttons {
  display: flex;
  margin-left: -16px;
}
input.submit {
  display: none;
}
input.panel_button {
  background-color: whitesmoke;
  padding: 12px;
  box-sizing: border-box;
  font-weight: bold;
  border: 0 none;
  border-radius: 4px;
  margin-left: 16px;
  flex-grow: 1;
}
input.submit {
  background-color: #e67e22;
  color: white;
}
.panel_button:hover {
  background-color: lightgray;
}
input.submit:hover {
  background-color: #f39c12;
}
.flag {
  visibility: hidden;
}
.flagged {
  background-color: pink !important;
}
/* label:hover {
  background-color: lightgray;
} */
.overlay {
  position: absolute;
  height: 100vh;
  width: 100vw;
  position: fixed;
  z-index: 1;
  background-color: rgba(0, 0, 0, 0.7);
  top: 0;
  left: 0;
}
.loading {
  justify-content: center;
  align-items: center;
}

.invisible {
  display: none !important;
}
.screenshot {
  visibility: hidden;
}
.screenshot_logo {
  display: none;
  flex-grow: 1;
  text-align: center;
  padding: 4px;
  box-sizing: border-box;
  margin-left: 16px;
}
.screenshot_logo img {
  height: 38px;
}