.input_text {
  resize: none;
  width: 100%;
  font-size: 18px;
  outline: none;
  height: 100%;
  background-color: white;
  border: solid 1px lightgray;
  border-radius: 2px;
  box-sizing: border-box;
  padding: 4px;
  font-family: monospace;
}
.input_text_saliency {
  display: none;
}
